@@ -1,12 +1,13 @@
-use 5.008;    # utf8
+use 5.006;    # our
 use strict;
 use warnings;
-use utf8;
 
 package CPAN::Changes::Markdown::Role::Filter::Rule::PlainText;
-$CPAN::Changes::Markdown::Role::Filter::Rule::PlainText::VERSION = '1.000000';
+
 # ABSTRACT: A rule that only filters 'plaintext' nodes.
 
+our $VERSION = '1.000001';
+
 our $AUTHORITY = 'cpan:KENTNL'; # AUTHORITY
 
 
@@ -77,7 +78,7 @@ CPAN::Changes::Markdown::Role::Filter::Rule::PlainText - A rule that only filter
 
 =head1 VERSION
 
-version 1.000000
+version 1.000001
 
 =head1 SYNOPSIS
 
@@ -113,11 +114,11 @@ version 1.000000
 
 =head1 AUTHOR
 
-Kent Fredric <kentfredric@gmail.com>
+Kent Fredric <kentnl@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Kent Fredric <kentfredric@gmail.com>.
+This software is copyright (c) 2015 by Kent Fredric <kentfredric@gmail.com>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
